@@ -14,7 +14,7 @@ weigthpath = os.path.join(this_dir, "weights", "Model_deda.h5")
 def check_de(string):
     with open(tokenizerpath, 'rb') as handle:
         turkish_tokenizer = pickle.load(handle)
-    model = load_model(weigthpath, custom_objects=tf.keras.metrics.AUC(name='auc'))
+    model = load_model(weigthpath, custom_objects= 'auc')
     tokens = turkish_tokenizer.texts_to_sequences(string)
     tokens_pad = pad_sequences(tokens, maxlen=7)
     print(tokens)
